<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/home/homeConfig/list',
        newUrl: 'flower/api/home/homeConfig/new',
        editUrl: 'flower/api/home/homeConfig/edit',
        deleteUrl: 'flower/api/home/homeConfig/delete',
        dialogNeedRequest: true,
        persistSelection: true,
        columns: [
          { type: 'selection' },
          { label: '主标题', prop: 'mainTitle' },
          { label: '副标题', prop: 'subTitle' },
          { label: '按钮1文本', prop: 'btnText1' },
          { label: '按钮2文本', prop: 'btnText2' },
          { label: '按钮1图标', prop: 'btnIcon1' },
          { label: '按钮2图标', prop: 'btnIcon2' },
          { label: '图标1颜色', prop: 'iconColor1' },
          { label: '图标2颜色', prop: 'iconColor2' },
          { label: '动作类型', prop: 'actionType' },
          { label: '动作目标', prop: 'actionTarget' },
          { label: '状态', prop: 'statusStr' },
          { label: '版本号', prop: 'version' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: '主标题', id: 'mainTitle', type: 'input' },
              { label: '版本号', id: 'version', type: 'input' },
            ],
          },
        ],
        form: [
          {
            label: '主标题：',
            id: 'mainTitle',
            type: 'input',
            rules: {
              required: true,
              message: '请输入标题',
              trigger: 'blur',
            },
          },
          {
            label: '副标题：',
            id: 'subTitle',
            type: 'input',
            rules: {
              required: true,
              message: '请输入副标题',
              trigger: 'blur',
            },
          },
          {
            label: '按钮1文本：',
            id: 'btnText1',
            type: 'input',
            rules: {
              required: true,
              message: '请输入按钮1文本',
              trigger: 'blur',
            },
          },{
            label: '按钮2文本：',
            id: 'btnText2',
            type: 'input',
            rules: {
              required: true,
              message: '请输入按钮2文本',
              trigger: 'blur',
            },
          },{
            label: '按钮1图标：',
            id: 'btnIcon1',
            type: 'input',
            rules: {
              required: true,
              message: '请输入按钮1图标',
              trigger: 'blur',
            },
          },{
            label: '按钮2图标：',
            id: 'btnIcon2',
            type: 'input',
            rules: {
              required: true,
              message: '请输入按钮2图标',
              trigger: 'blur',
            },
          },{
            label: '图标1颜色：',
            id: 'iconColor1',
            type: 'input',
            rules: {
              required: true,
              message: '请输入图标1颜色',
              trigger: 'blur',
            },
          },{
            label: '图标2颜色：',
            id: 'iconColor2',
            type: 'input',
            rules: {
              required: true,
              message: '请输入图标2颜色',
              trigger: 'blur',
            },
          },{
            label: '动作类型：',
            id: 'actionType',
            type: 'input',
            rules: {
              required: true,
              message: '请输入动作类型',
              trigger: 'blur',
            },
          },{
            label: '动作目标：',
            id: 'actionTarget',
            type: 'input',
            rules: {
              required: true,
              message: '请输入动作目标',
              trigger: 'blur',
            },
          },{
            label: '版本号：',
            id: 'version',
            type: 'input',
            rules: {
              required: true,
              message: '请输入版本号',
              trigger: 'blur',
            },
          },
        ],
        extraButtons: [
          {
            text: (row) => (row.status === 'unpublished' ? '发布' : '下架'),
            atClick: async (row) => {
              const action = row.status === 'unpublished' ? '发布' : '下架'
              try {
                await this.$elBusUtil.confirm(`确定要${action}吗？`)
                const { code } = await this.$elBusHttp.request(
                  'flower/api/home/homeConfig/changeStatus',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success(`${action}成功`)
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        headerButtons: [
          {
            text: '批量删除',
            type: 'danger',
            disabled: (selected) => selected.length === 0,
            atClick: async (selected) => {
              try {
                await this.$elBusUtil.confirm(
                  `确定要批量删除这${selected.length}个配置吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/announcement/page/delete/batch',
                  {
                    method: 'post',
                    data: {
                      ids: selected.map((item) => item.id),
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('操作成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '主页配置管理',
    }
  },
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-upload {
    &-list__item {
      width: 345px;
      height: 128px;
    }
    &.el-upload--picture-card {
      width: 345px;
      height: 128px;
    }
  }
}
</style>
